@@ -101,8 +101,8 @@ def exview(rotoid, index=-1, seek_to={}, fetch=True, compose=False):
         if compose:
             exv.compose()
         if seek_to:
-            exv.seek_to(**seek_to)
-        if fetch:
+            exv.seek_to(**seek_to, fetch=fetch)
+        elif fetch:
             exv.fetch()
         yield exv
     finally:
@@ -743,10 +743,10 @@ class ExView():
 
         Only relevant for detail views, return the key components before
         the last one.
-        
+
         The views, as classified by Sage, may either be header, detail, flat
-        or batch.  Both detail, and headers with composite keys, may be 
-        enumerated.        
+        or batch.  Both detail, and headers with composite keys, may be
+        enumerated.
 
         :returns: {field: value, field: value...}
         """
